diff --git a/include/asterisk/res_pjsip.h b/include/asterisk/res_pjsip.h
index 37b7662..933fed0 100644
--- a/include/asterisk/res_pjsip.h
+++ b/include/asterisk/res_pjsip.h
@@ -201,6 +201,8 @@ struct ast_sip_contact_status {
 	int64_t rtt;
 	/*! Last status for a contact (default - unavailable) */
 	enum ast_sip_contact_status_type last_status;
+	/*! SHA1 hash of this object's sorcery ID */
+	char hash[41];
 };
 
 /*!
diff --git a/res/res_pjsip/location.c b/res/res_pjsip/location.c
index 2e0d84b..e2507cb 100644
--- a/res/res_pjsip/location.c
+++ b/res/res_pjsip/location.c
@@ -763,12 +763,12 @@ static int cli_contact_print_header(void *obj, void *arg, int flags)
 {
 	struct ast_sip_cli_context *context = arg;
 	int indent = CLI_INDENT_TO_SPACES(context->indent_level);
-	int filler = CLI_LAST_TABSTOP - indent - 18;
+	int filler = CLI_LAST_TABSTOP - indent - 26;
 
 	ast_assert(context->output_buffer != NULL);
 
 	ast_str_append(&context->output_buffer, 0,
-		"%*s:  <Aor/ContactUri%*.*s>  <Status....>  <RTT(ms)..>\n",
+		"%*s:  <Aor/ContactUri%*.*s> <Hash......> <Status....>  <RTT(ms)..>\n",
 		indent, "Contact", filler, filler, CLI_HEADER_FILLER);
 
 	return 0;
@@ -790,13 +790,14 @@ static int cli_contact_print_body(void *obj, void *arg, int flags)
 	ast_assert(context->output_buffer != NULL);
 
 	indent = CLI_INDENT_TO_SPACES(context->indent_level);
-	flexwidth = CLI_LAST_TABSTOP - indent - 2;
+	flexwidth = CLI_LAST_TABSTOP - indent - 11;
 
-	ast_str_append(&context->output_buffer, 0, "%*s:  %-*.*s  %-12.12s  %11.3f\n",
+	ast_str_append(&context->output_buffer, 0, "%*s:  %-*.*s   %10.10s   %-11.11s %11.3f\n",
 		indent,
 		"Contact",
 		flexwidth, flexwidth,
 		wrapper->contact_id,
+		status->hash,
 		ast_sip_get_contact_short_status_label(status ? status->status : UNKNOWN),
 		(status && (status->status != UNKNOWN) ? ((long long) status->rtt) / 1000.0 : NAN));
 
diff --git a/res/res_pjsip/pjsip_options.c b/res/res_pjsip/pjsip_options.c
index b172489..465aa6f 100644
--- a/res/res_pjsip/pjsip_options.c
+++ b/res/res_pjsip/pjsip_options.c
@@ -75,7 +75,7 @@ static void *contact_status_alloc(const char *name)
 		ast_log(LOG_ERROR, "Unable to allocate ast_sip_contact_status\n");
 		return NULL;
 	}
-
+	ast_sha1_hash(status->hash, name);
 	status->status = UNKNOWN;
 
 	return status;
@@ -102,7 +102,7 @@ struct ast_sip_contact_status *ast_res_pjsip_find_or_create_contact_status(const
 			contact->uri);
 		return NULL;
 	}
-
+	ast_sha1_hash(status->hash, ast_sorcery_object_get_id(contact));
 	status->status = UNKNOWN;
 	status->rtt_start = ast_tv(0, 0);
 	status->rtt = 0;
@@ -162,7 +162,7 @@ static void update_contact_status(const struct ast_sip_contact *contact,
 	update->rtt_start = ast_tv(0, 0);
 
 	ast_statsd_log_full_va("PJSIP.contacts.%s.rtt", AST_STATSD_TIMER,
-		update->rtt / 1000, 1.0, ast_sorcery_object_get_id(update));
+		update->rtt / 1000, 1.0, update->hash);
 	ast_test_suite_event_notify("AOR_CONTACT_QUALIFY_RESULT",
 		"Contact: %s\r\n"
 		"Status: %s\r\n"
@@ -1014,6 +1014,8 @@ int ast_sip_initialize_sorcery_qualify(void)
 		"0.0", rtt_start_handler, rtt_start_to_str, NULL, 0, 0);
 	ast_sorcery_object_field_register_nodoc(sorcery, CONTACT_STATUS, "rtt",
 		"0", OPT_UINT_T, 1, FLDSET(struct ast_sip_contact_status, rtt));
+	ast_sorcery_object_field_register_nodoc(sorcery, CONTACT_STATUS, "hash",
+		"", OPT_CHAR_ARRAY_T, 0, CHARFLDSET(struct ast_sip_contact_status, hash));
 
 	return 0;
 }
